/*
 * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_uz_Cyrl extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] GMT = new String[] {
               "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Cook = new String[] {
               "\u041a\u0443\u043a \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u0443\u043a \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u044f\u0440\u0438\u043c \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u0443\u043a \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Cuba = new String[] {
               "\u041a\u0443\u0431\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u0443\u0431\u0430 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u0443\u0431\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Fiji = new String[] {
               "\u0424\u0438\u0436\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0424\u0438\u0436\u0438 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0424\u0438\u0436\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Gulf = new String[] {
               "\u041a\u045e\u0440\u0444\u0430\u0437 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hovd = new String[] {
               "\u0425\u043e\u0432\u0434 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0425\u043e\u0432\u0434 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0425\u043e\u0432\u0434 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Iran = new String[] {
               "\u042d\u0440\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u042d\u0440\u043e\u043d \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u042d\u0440\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Niue = new String[] {
               "\u041d\u0438\u0443\u0435 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Omsk = new String[] {
               "\u041e\u043c\u0441\u043a \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041e\u043c\u0441\u043a \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041e\u043c\u0441\u043a \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Peru = new String[] {
               "\u041f\u0435\u0440\u0443 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041f\u0435\u0440\u0443 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041f\u0435\u0440\u0443 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Truk = new String[] {
               "\u0427\u0443\u0443\u043a \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wake = new String[] {
               "\u0423\u044d\u0439\u043a \u043e\u0440\u043e\u043b\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chile = new String[] {
               "\u0427\u0438\u043b\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0427\u0438\u043b\u0438 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0427\u0438\u043b\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] China = new String[] {
               "\u0425\u0438\u0442\u043e\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0425\u0438\u0442\u043e\u0439 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0425\u0438\u0442\u043e\u0439 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Cocos = new String[] {
               "\u041a\u043e\u043a\u043e\u0441 \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Davis = new String[] {
               "\u0414\u044d\u0432\u0438\u0441 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] India = new String[] {
               "\u04b2\u0438\u043d\u0434\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Japan = new String[] {
               "\u042f\u043f\u043e\u043d\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u042f\u043f\u043e\u043d\u0438\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u042f\u043f\u043e\u043d\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Korea = new String[] {
               "\u041a\u043e\u0440\u0435\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u043e\u0440\u0435\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u043e\u0440\u0435\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Nauru = new String[] {
               "\u041d\u0430\u0443\u0440\u0443 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Nepal = new String[] {
               "\u041d\u0435\u043f\u0430\u043b \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Palau = new String[] {
               "\u041f\u0430\u043b\u0430\u0443 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Samoa = new String[] {
               "\u0421\u0430\u043c\u043e\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0421\u0430\u043c\u043e\u0430 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0421\u0430\u043c\u043e\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Syowa = new String[] {
               "\u0421\u044c\u043e\u0432\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tonga = new String[] {
               "\u0422\u043e\u043d\u0433\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0422\u043e\u043d\u0433\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0422\u043e\u043d\u0433\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Alaska = new String[] {
               "\u0410\u043b\u044f\u0441\u043a\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u043b\u044f\u0441\u043a\u0430 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u043b\u044f\u0441\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Amazon = new String[] {
               "\u0410\u043c\u0430\u0437\u043e\u043d\u043a\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u043c\u0430\u0437\u043e\u043d\u043a\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u043c\u0430\u0437\u043e\u043d\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Azores = new String[] {
               "\u0410\u0437\u043e\u0440 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u0437\u043e\u0440 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u0437\u043e\u0440 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Bhutan = new String[] {
               "\u0411\u0443\u0442\u0430\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Brunei = new String[] {
               "\u0411\u0440\u0443\u043d\u0435\u0439 \u0414\u0430\u0440\u0443\u0441\u0441\u0430\u043b\u043e\u043c \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Easter = new String[] {
               "\u041f\u0430\u0441\u0445\u0438 \u043e\u0440\u043e\u043b\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041f\u0430\u0441\u0445\u0438 \u043e\u0440\u043e\u043b\u0438 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041f\u0430\u0441\u0445\u0438 \u041e\u0440\u043e\u043b\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Guyana = new String[] {
               "\u0413\u0430\u0439\u0430\u043d\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Israel = new String[] {
               "\u0418\u0441\u0440\u043e\u0438\u043b \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0418\u0441\u0440\u043e\u0438\u043b \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0418\u0441\u0440\u043e\u0438\u043b \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Kosrae = new String[] {
               "\u041a\u043e\u0441\u0440\u0430\u0435 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mawson = new String[] {
               "\u041c\u043e\u0443\u0432\u0441\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Moscow = new String[] {
               "\u041c\u043e\u0441\u043a\u0432\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u043e\u0441\u043a\u0432\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u043e\u0441\u043a\u0432\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Ponape = new String[] {
               "\u041f\u043e\u043d\u0430\u043f\u0435 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tahiti = new String[] {
               "\u0422\u0430\u0438\u0442\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Taipei = new String[] {
               "\u0422\u0430\u0439\u043f\u0435\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0422\u0430\u0439\u043f\u0435\u0439 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0422\u0430\u0439\u043f\u0435\u0439 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Tuvalu = new String[] {
               "\u0422\u0443\u0432\u0430\u043b\u0443 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Vostok = new String[] {
               "\u0412\u043e\u0441\u0442\u043e\u043a \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Wallis = new String[] {
               "\u0423\u044d\u043b\u043b\u0438\u0441 \u0432\u0430 \u0424\u0443\u0442\u0443\u043d\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Arabian = new String[] {
               "\u0410\u0440\u0430\u0431\u0438\u0441\u0442\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u0440\u0430\u0431\u0438\u0441\u0442\u043e\u043d \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u0440\u0430\u0431\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Armenia = new String[] {
               "\u0410\u0440\u043c\u0430\u043d\u0438\u0441\u0442\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u0440\u043c\u0430\u043d\u0438\u0441\u0442\u043e\u043d \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u0440\u0430\u043c\u043d\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Bolivia = new String[] {
               "\u0411\u043e\u043b\u0438\u0432\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Chatham = new String[] {
               "\u0427\u0430\u0442\u0445\u0430\u043c \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0427\u0430\u0442\u0445\u0430\u043c \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0427\u0430\u0442\u0445\u0430\u043c \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Ecuador = new String[] {
               "\u042d\u043a\u0432\u0430\u0434\u043e\u0440 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gambier = new String[] {
               "\u0413\u0430\u043c\u0431\u0438\u0435\u0440 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Georgia = new String[] {
               "\u0413\u0440\u0443\u0437\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0413\u0440\u0443\u0437\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0413\u0440\u0443\u0437\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Irkutsk = new String[] {
               "\u0418\u0440\u043a\u0443\u0442\u0441\u043a \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0418\u0440\u043a\u0443\u0442\u0441\u043a \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0418\u0440\u043a\u0443\u0442\u0441\u043a \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Magadan = new String[] {
               "\u041c\u0430\u0433\u0430\u0434\u0430\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u0430\u0433\u0430\u0434\u0430\u043d \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u0430\u0433\u0430\u0434\u0430\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Myanmar = new String[] {
               "\u041c\u044c\u044f\u043d\u043c\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Norfolk = new String[] {
               "\u041d\u043e\u0440\u0444\u043e\u043b\u043a \u043e\u0440\u043e\u043b\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041d\u043e\u0440\u0444\u043e\u043b\u043a \u043e\u0440\u043e\u043b\u0438 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041d\u043e\u0440\u0444\u043e\u043b\u043a \u043e\u0440\u043e\u043b\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Noronha = new String[] {
               "\u0424\u0435\u0440\u043d\u0430\u043d\u0434\u043e \u0434\u0435 \u041d\u043e\u0440\u043e\u043d\u044c\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0424\u0435\u0440\u043d\u0430\u043d\u0434\u043e \u0434\u0435 \u041d\u043e\u0440\u043e\u043d\u044c\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0424\u0435\u0440\u043d\u0430\u043d\u0434\u043e \u0434\u0435 \u041d\u043e\u0440\u043e\u043d\u044c\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Reunion = new String[] {
               "\u0420\u0435\u044e\u043d\u044c\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Rothera = new String[] {
               "\u0420\u043e\u0442\u0435\u0440\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Solomon = new String[] {
               "\u0421\u043e\u043b\u043e\u043c\u043e\u043d \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tokelau = new String[] {
               "\u0422\u043e\u043a\u0435\u043b\u0430\u0443 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uruguay = new String[] {
               "\u0423\u0440\u0443\u0433\u0432\u0430\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0423\u0440\u0443\u0433\u0432\u0430\u0439 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0423\u0440\u0443\u0433\u0432\u0430\u0439 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Vanuatu = new String[] {
               "\u0412\u0430\u043d\u0443\u0430\u0442\u0443 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0412\u0430\u043d\u0443\u0430\u0442\u0443 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0412\u0430\u043d\u0443\u0430\u0442\u0443 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Yakutsk = new String[] {
               "\u042f\u043a\u0443\u0442\u0441\u043a \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u042f\u043a\u0443\u0442\u0441\u043a \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u042f\u043a\u0443\u0442\u0441\u043a \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Atlantic = new String[] {
               "\u0410\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u0430 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Brasilia = new String[] {
               "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Chamorro = new String[] {
               "\u041a\u0430\u043c\u043e\u0440\u0440\u043e \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Colombia = new String[] {
               "\u041a\u043e\u043b\u0443\u043c\u0431\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u043e\u043b\u0443\u043c\u0431\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u043e\u043b\u0443\u043c\u0431\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Falkland = new String[] {
               "\u0424\u043e\u043b\u044c\u043a\u043b\u0435\u043d\u0434 \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0424\u043e\u043b\u044c\u043a\u043b\u0435\u043d\u0434 \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0424\u043e\u043b\u044c\u043a\u043b\u0435\u043d\u0434 \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Malaysia = new String[] {
               "\u041c\u0430\u043b\u0430\u0439\u0437\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Maldives = new String[] {
               "\u041c\u0430\u043b\u044c\u0434\u0438\u0432 \u043e\u0440\u043e\u043b\u043b\u0430\u0440",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mongolia = new String[] {
               "\u0423\u043b\u0430\u043d-\u0411\u0430\u0442\u043e\u0440 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0423\u043b\u0430\u043d-\u0411\u0430\u0442\u043e\u0440 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0423\u043b\u0430\u043d-\u0411\u0430\u0442\u043e\u0440 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Pakistan = new String[] {
               "\u041f\u043e\u043a\u0438\u0441\u0442\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041f\u043e\u043a\u0438\u0441\u0442\u043e\u043d \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041f\u043e\u043a\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Paraguay = new String[] {
               "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0439 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041f\u0430\u0440\u0430\u0433\u0432\u0430\u0439 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Pitcairn = new String[] {
               "\u041f\u0438\u0442\u043a\u0435\u0440\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Sakhalin = new String[] {
               "\u0421\u0430\u0445\u0430\u043b\u0438\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0421\u0430\u0445\u0430\u043b\u0438\u043d \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0421\u0430\u0445\u0430\u043b\u0438\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Suriname = new String[] {
               "\u0421\u0443\u0440\u0438\u043d\u0430\u043c \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Argentina = new String[] {
               "\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0410\u0440\u0433\u0435\u043d\u0442\u0438\u043d\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Christmas = new String[] {
               "\u0420\u043e\u0436\u0434\u0435\u0441\u0442\u0432\u043e \u043e\u0440\u043e\u043b\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Galapagos = new String[] {
               "\u0413\u0430\u043b\u0430\u043f\u0430\u0433\u043e\u0441 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hong_Kong = new String[] {
               "\u0413\u043e\u043d\u043a\u043e\u043d\u0433 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0413\u043e\u043d\u043a\u043e\u043d\u0433 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0413\u043e\u043d\u043a\u043e\u043d\u0433 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Indochina = new String[] {
               "\u04b2\u0438\u043d\u0434-\u0425\u0438\u0442\u043e\u0439 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kyrgystan = new String[] {
               "\u049a\u0438\u0440\u0493\u0438\u0437\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Lord_Howe = new String[] {
               "\u041b\u043e\u0440\u0434 \u0425\u043e\u0432\u0435 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041b\u043e\u0440\u0434 \u0425\u043e\u0432\u0435 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041b\u043e\u0440\u0434 \u0425\u043e\u0432\u0435 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Marquesas = new String[] {
               "\u041c\u0430\u0440\u043a\u0435\u0437\u0430\u0441 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mauritius = new String[] {
               "\u041c\u0430\u0432\u0440\u0438\u043a\u0438\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u0430\u0432\u0440\u0438\u043a\u0438\u0439 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u0430\u0432\u0440\u0438\u043a\u0438\u0439 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Singapore = new String[] {
               "\u0421\u0438\u043d\u0433\u0430\u043f\u0443\u0440 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Venezuela = new String[] {
               "\u0412\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Volgograd = new String[] {
               "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0412\u043e\u043b\u0433\u043e\u0433\u0440\u0430\u0434 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Azerbaijan = new String[] {
               "\u041e\u0437\u0430\u0440\u0431\u0430\u0439\u0436\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041e\u0437\u0430\u0440\u0431\u0430\u0439\u0436\u043e\u043d \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041e\u0437\u0430\u0440\u0431\u0430\u0439\u0436\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Bangladesh = new String[] {
               "\u0411\u0430\u043d\u0433\u043b\u0430\u0434\u0435\u0448 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0411\u0430\u043d\u0433\u043b\u0430\u0434\u0435\u0448 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0411\u0430\u043d\u0433\u043b\u0430\u0434\u0435\u0448 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Cape_Verde = new String[] {
               "\u041a\u0430\u0431\u043e-\u0412\u0435\u0440\u0434\u0435 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u0430\u0431\u043e-\u0412\u0435\u0440\u0434\u0435 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u0430\u0431\u043e-\u0412\u0435\u0440\u0434\u0435 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] EMPTY_ZONE = new String[] {
               "",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] East_Timor = new String[] {
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0422\u0438\u043c\u043e\u0440 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Seychelles = new String[] {
               "\u0421\u0435\u0439\u0448\u0435\u043b \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tajikistan = new String[] {
               "\u0422\u043e\u0436\u0438\u043a\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Uzbekistan = new String[] {
               "\u040e\u0437\u0431\u0435\u043a\u0438\u0441\u0442\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u040e\u0437\u0431\u0435\u043a\u0438\u0441\u0442\u043e\u043d \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u040e\u0437\u0431\u0435\u043a\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Afghanistan = new String[] {
               "\u0410\u0444\u0493\u043e\u043d\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Krasnoyarsk = new String[] {
               "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041a\u0440\u0430\u0441\u043d\u043e\u044f\u0440\u0441\u043a \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] New_Zealand = new String[] {
               "\u042f\u043d\u0433\u0438 \u0417\u0435\u043b\u0430\u043d\u0434\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u042f\u043d\u0433\u0438 \u0417\u0435\u043b\u0430\u043d\u0434\u0438\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u042f\u043d\u0433\u0438 \u0417\u0435\u043b\u0430\u043d\u0434\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Novosibirsk = new String[] {
               "\u041d\u043e\u0432\u043e\u0441\u0438\u0431\u0438\u0440\u0441\u043a \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041d\u043e\u0432\u043e\u0441\u0438\u0431\u0438\u0440\u0441\u043a \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041d\u043e\u0432\u043e\u0441\u0438\u0431\u0438\u0440\u0441\u043a \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Philippines = new String[] {
               "\u0424\u0438\u043b\u0438\u043f\u043f\u0438\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0424\u0438\u043b\u0438\u043f\u043f\u0438\u043d \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0424\u0438\u043b\u0438\u043f\u043f\u0438\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Vladivostok = new String[] {
               "\u0412\u043b\u0430\u0434\u0438\u0432\u043e\u0441\u0442\u043e\u043a \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0412\u043b\u0430\u0434\u0438\u0432\u043e\u0441\u0442\u043e\u043a \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0412\u043b\u0430\u0434\u0438\u0432\u043e\u0441\u0442\u043e\u043a \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Indian_Ocean = new String[] {
               "\u04b2\u0438\u043d\u0434 \u043e\u043a\u0435\u0430\u043d\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Line_Islands = new String[] {
               "\u041b\u0430\u0439\u043d \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Newfoundland = new String[] {
               "\u041d\u044c\u044e\u0444\u0430\u0443\u043d\u0434\u043b\u0435\u043d\u0434 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041d\u044c\u044e\u0444\u0430\u0443\u043d\u0434\u043b\u0435\u043d\u0434 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041d\u044c\u044e\u0444\u0430\u0443\u043d\u0434\u043b\u0435\u043d\u0434 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Turkmenistan = new String[] {
               "\u0422\u0443\u0440\u043a\u043c\u0430\u043d\u0438\u0441\u0442\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0422\u0443\u0440\u043a\u043c\u0430\u043d\u0438\u0441\u0442\u043e\u043d \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0422\u0443\u0440\u043a\u043c\u0430\u043d\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] French_Guiana = new String[] {
               "\u0424\u0440\u0430\u043d\u0446\u0443\u0437 \u0413\u0432\u0438\u0430\u043d\u0430\u0441\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] New_Caledonia = new String[] {
               "\u042f\u043d\u0433\u0438 \u041a\u0430\u043b\u0435\u0434\u043e\u043d\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u042f\u043d\u0433\u0438 \u041a\u0430\u043b\u0435\u0434\u043e\u043d\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u042f\u043d\u0433\u0438 \u041a\u0430\u043b\u0435\u0434\u043e\u043d\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] South_Georgia = new String[] {
               "\u0416\u0430\u043d\u0443\u0431\u0438\u0439 \u0414\u0436\u043e\u0440\u0434\u0436\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Yekaterinburg = new String[] {
               "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0440\u0433 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0440\u0433 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0431\u0443\u0440\u0433 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Africa_Central = new String[] {
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Africa_Eastern = new String[] {
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Africa_Western = new String[] {
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] DumontDUrville = new String[] {
               "\u0414\u0443\u043c\u043e\u043d\u0442-\u0434-\u0423\u0440\u0432\u0438\u043b \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Europe_Central = new String[] {
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Europe_Eastern = new String[] {
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Europe_Western = new String[] {
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0415\u0432\u0440\u043e\u043f\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Africa_Southern = new String[] {
               "\u0416\u0430\u043d\u0443\u0431\u0438\u0439 \u0410\u0444\u0440\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] America_Central = new String[] {
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u043c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u043c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430",
               "",
            };
        final String[] America_Eastern = new String[] {
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0448\u0430\u0440\u049b\u0438\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0448\u0430\u0440\u049b\u0438\u0439 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0448\u0430\u0440\u049b\u0438\u0439 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] America_Pacific = new String[] {
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u0438\u043d\u0447 \u043e\u043a\u0435\u0430\u043d\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u0438\u043d\u0447 \u043e\u043a\u0435\u0430\u043d\u0438 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u0438\u043d\u0447 \u043e\u043a\u0435\u0430\u043d\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] French_Southern = new String[] {
               "\u0424\u0440\u0430\u043d\u0446\u0443\u0437 \u0436\u0430\u043d\u0443\u0431\u0438\u0439 \u0432\u0430 \u0410\u043d\u0442\u0430\u0440\u043a\u0442\u0438\u043a\u0430 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Gilbert_Islands = new String[] {
               "\u0413\u0438\u043b\u0431\u0435\u0440\u0442 \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Hawaii_Aleutian = new String[] {
               "\u0413\u0430\u0432\u0430\u0439\u0438-\u0430\u043b\u0435\u0443\u0442 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0413\u0430\u0432\u0430\u0439\u0438-\u0430\u043b\u0435\u0443\u0442 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0413\u0430\u0432\u0430\u0439\u0438-\u0430\u043b\u0435\u0443\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Phoenix_Islands = new String[] {
               "\u0424\u0435\u043d\u0438\u043a\u0441 \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Pierre_Miquelon = new String[] {
               "\u0421\u0435\u043d\u0442-\u041f\u044c\u0435\u0440 \u0432\u0430 \u041c\u0438\u043a\u0435\u043b\u043e\u043d \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0421\u0435\u043d\u0442-\u041f\u044c\u0435\u0440 \u0432\u0430 \u041c\u0438\u043a\u0435\u043b\u043e\u043d \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0421\u0435\u043d\u0442-\u041f\u044c\u0435\u0440 \u0432\u0430 \u041c\u0438\u043a\u0435\u043b\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] America_Mountain = new String[] {
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u043e\u0493 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u043e\u0493 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0438\u043c\u043e\u043b\u0438\u0439 \u0410\u043c\u0435\u0440\u0438\u043a\u0430 \u0442\u043e\u0493 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Marshall_Islands = new String[] {
               "\u041c\u0430\u0440\u0448\u0430\u043b\u043b \u043e\u0440\u043e\u043b\u043b\u0430\u0440\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Papua_New_Guinea = new String[] {
               "\u041f\u0430\u043f\u0443\u0430-\u042f\u043d\u0433\u0438 \u0413\u0432\u0438\u043d\u0435\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_Central = new String[] {
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Australia_Eastern = new String[] {
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Australia_Western = new String[] {
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Greenland_Eastern = new String[] {
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Greenland_Western = new String[] {
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0413\u0440\u0435\u043d\u043b\u0430\u043d\u0434\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final String[] Indonesia_Central = new String[] {
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0418\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Indonesia_Eastern = new String[] {
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u0418\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Indonesia_Western = new String[] {
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u0418\u043d\u0434\u043e\u043d\u0435\u0437\u0438\u044f \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Eastern = new String[] {
               "\u0428\u0430\u0440\u049b\u0438\u0439 \u049a\u043e\u0437\u043e\u0493\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kazakhstan_Western = new String[] {
               "\u0492\u0430\u0440\u0431\u0438\u0439 \u049a\u043e\u0437\u043e\u0493\u0438\u0441\u0442\u043e\u043d \u0432\u0430\u049b\u0442\u0438",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Australia_CentralWestern = new String[] {
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0492\u0430\u0440\u0431\u0438\u0439 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0492\u0430\u0440\u0431\u0438\u0439 \u043a\u0443\u043d\u0434\u0443\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
               "",
               "\u041c\u0430\u0440\u043a\u0430\u0437\u0438\u0439 \u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f \u0492\u0430\u0440\u0431\u0438\u0439 \u0432\u0430\u049b\u0442\u0438",
               "",
            };
        final Object[][] data = new Object[][] {
            { "America/Los_Angeles", America_Pacific },
            { "America/Denver", America_Mountain },
            { "America/Phoenix", America_Mountain },
            { "America/Chicago", America_Central },
            { "America/New_York", America_Eastern },
            { "America/Indianapolis", America_Eastern },
            { "Pacific/Honolulu", Hawaii_Aleutian },
            { "America/Anchorage", Alaska },
            { "America/Halifax", Atlantic },
            { "America/Sitka", Alaska },
            { "America/St_Johns", Newfoundland },
            { "Europe/Paris", Europe_Central },
            { "GMT", GMT },
            { "Asia/Jerusalem", Israel },
            { "Asia/Tokyo", Japan },
            { "Europe/Bucharest", Europe_Eastern },
            { "Asia/Shanghai", China },
            { "UTC", EMPTY_ZONE },
            { "ACT", Australia_Central },
            { "AET", Australia_Eastern },
            { "ART", Europe_Eastern },
            { "AST", Alaska },
            { "BET", Brasilia },
            { "BST", Bangladesh },
            { "CAT", Africa_Central },
            { "CNT", Newfoundland },
            { "CST", America_Central },
            { "CTT", China },
            { "EAT", Africa_Eastern },
            { "ECT", Europe_Central },
            { "JST", Japan },
            { "NET", Armenia },
            { "NST", New_Zealand },
            { "PLT", Pakistan },
            { "PNT", America_Mountain },
            { "PRT", Atlantic },
            { "PST", America_Pacific },
            { "SST", Solomon },
            { "CST6CDT", America_Central },
            { "EST5EDT", America_Eastern },
            { "Etc/GMT", GMT },
            { "MST7MDT", America_Mountain },
            { "PST8PDT", America_Pacific },
            { "Asia/Aden", Arabian },
            { "Asia/Baku", Azerbaijan },
            { "Asia/Dili", East_Timor },
            { "Asia/Gaza", Europe_Eastern },
            { "Asia/Hovd", Hovd },
            { "Asia/Omsk", Omsk },
            { "Asia/Oral", Kazakhstan_Western },
            { "Asia/Amman", Europe_Eastern },
            { "Asia/Aqtau", Kazakhstan_Western },
            { "Asia/Chita", Yakutsk },
            { "Asia/Dhaka", Bangladesh },
            { "Asia/Dubai", Gulf },
            { "Asia/Kabul", Afghanistan },
            { "Asia/Macau", China },
            { "Asia/Qatar", Arabian },
            { "Asia/Seoul", Korea },
            { "Africa/Juba", Africa_Central },
            { "Africa/Lome", GMT },
            { "Asia/Almaty", Kazakhstan_Eastern },
            { "Asia/Aqtobe", Kazakhstan_Western },
            { "Asia/Atyrau", Kazakhstan_Western },
            { "Asia/Beirut", Europe_Eastern },
            { "Asia/Brunei", Brunei },
            { "Asia/Harbin", China },
            { "Asia/Hebron", Europe_Eastern },
            { "Asia/Kuwait", Arabian },
            { "Asia/Manila", Philippines },
            { "Asia/Muscat", Gulf },
            { "Asia/Riyadh", Arabian },
            { "Asia/Saigon", Indochina },
            { "Asia/Taipei", Taipei },
            { "Asia/Tehran", Iran },
            { "Europe/Kiev", Europe_Eastern },
            { "Europe/Oslo", Europe_Central },
            { "Europe/Riga", Europe_Eastern },
            { "Europe/Rome", Europe_Central },
            { "Indian/Mahe", Seychelles },
            { "Pacific/Yap", Truk },
            { "Africa/Accra", GMT },
            { "Africa/Cairo", Europe_Eastern },
            { "Africa/Ceuta", Europe_Central },
            { "Africa/Dakar", GMT },
            { "Africa/Lagos", Africa_Western },
            { "Africa/Tunis", Europe_Central },
            { "America/Adak", Hawaii_Aleutian },
            { "America/Lima", Peru },
            { "America/Nome", Alaska },
            { "Asia/Baghdad", Arabian },
            { "Asia/Bahrain", Arabian },
            { "Asia/Bangkok", Indochina },
            { "Asia/Bishkek", Kyrgystan },
            { "Asia/Colombo", India },
            { "Asia/Irkutsk", Irkutsk },
            { "Asia/Jakarta", Indonesia_Western },
            { "Asia/Karachi", Pakistan },
            { "Asia/Kuching", Malaysia },
            { "Asia/Magadan", Magadan },
            { "Asia/Nicosia", Europe_Eastern },
            { "Asia/Rangoon", Myanmar },
            { "Asia/Tbilisi", Georgia },
            { "Asia/Thimphu", Bhutan },
            { "Asia/Yakutsk", Yakutsk },
            { "Asia/Yerevan", Armenia },
            { "Europe/Malta", Europe_Central },
            { "Europe/Minsk", Moscow },
            { "Europe/Sofia", Europe_Eastern },
            { "Europe/Vaduz", Europe_Central },
            { "Indian/Cocos", Cocos },
            { "Pacific/Fiji", Fiji },
            { "Pacific/Guam", Chamorro },
            { "Pacific/Niue", Niue },
            { "Pacific/Truk", Truk },
            { "Pacific/Wake", Wake },
            { "SystemV/AST4", Atlantic },
            { "SystemV/CST6", America_Central },
            { "SystemV/EST5", America_Eastern },
            { "SystemV/MST7", America_Mountain },
            { "SystemV/PST8", Pitcairn },
            { "SystemV/YST9", Gambier },
            { "Africa/Asmera", Africa_Eastern },
            { "Africa/Bamako", GMT },
            { "Africa/Bangui", Africa_Western },
            { "Africa/Banjul", GMT },
            { "Africa/Bissau", GMT },
            { "Africa/Douala", Africa_Western },
            { "Africa/Harare", Africa_Central },
            { "Africa/Kigali", Africa_Central },
            { "Africa/Luanda", Africa_Western },
            { "Africa/Lusaka", Africa_Central },
            { "Africa/Malabo", Africa_Western },
            { "Africa/Maputo", Africa_Central },
            { "Africa/Maseru", Africa_Southern },
            { "Africa/Niamey", Africa_Western },
            { "America/Aruba", Atlantic },
            { "America/Bahia", Brasilia },
            { "America/Belem", Brasilia },
            { "America/Boise", America_Mountain },
            { "America/Jujuy", Argentina },
            { "America/Thule", Atlantic },
            { "Asia/Ashgabat", Turkmenistan },
            { "Asia/Calcutta", India },
            { "Asia/Damascus", Europe_Eastern },
            { "Asia/Dushanbe", Tajikistan },
            { "Asia/Jayapura", Indonesia_Eastern },
            { "Asia/Katmandu", Nepal },
            { "Asia/Khandyga", Yakutsk },
            { "Asia/Makassar", Indonesia_Central },
            { "Asia/Qostanay", Kazakhstan_Eastern },
            { "Asia/Sakhalin", Sakhalin },
            { "Asia/Tashkent", Uzbekistan },
            { "Asia/Ust-Nera", Vladivostok },
            { "Europe/Athens", Europe_Eastern },
            { "Europe/Berlin", Europe_Central },
            { "Europe/Dublin",
                new String[] {
                    "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
                    "",
                    "\u0418\u0440\u043b\u0430\u043d\u0434\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Jersey", GMT },
            { "Europe/Lisbon", Europe_Western },
            { "Europe/London",
                new String[] {
                    "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
                    "",
                    "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Madrid", Europe_Central },
            { "Europe/Monaco", Europe_Central },
            { "Europe/Moscow", Moscow },
            { "Europe/Prague", Europe_Central },
            { "Europe/Skopje", Europe_Central },
            { "Europe/Tirane", Europe_Central },
            { "Europe/Vienna", Europe_Central },
            { "Europe/Warsaw", Europe_Central },
            { "Europe/Zagreb", Europe_Central },
            { "Europe/Zurich", Europe_Central },
            { "Indian/Chagos", Indian_Ocean },
            { "Indian/Comoro", Africa_Eastern },
            { "Pacific/Efate", Vanuatu },
            { "Pacific/Nauru", Nauru },
            { "Pacific/Palau", Palau },
            { "SystemV/HST10", Hawaii_Aleutian },
            { "Africa/Abidjan", GMT },
            { "Africa/Algiers", Europe_Central },
            { "Africa/Conakry", GMT },
            { "Africa/Kampala", Africa_Eastern },
            { "Africa/Mbabane", Africa_Southern },
            { "Africa/Nairobi", Africa_Eastern },
            { "Africa/Tripoli", Europe_Eastern },
            { "America/Belize", America_Central },
            { "America/Bogota", Colombia },
            { "America/Cancun", America_Eastern },
            { "America/Cayman", America_Eastern },
            { "America/Cuiaba", Amazon },
            { "America/Dawson", America_Mountain },
            { "America/Guyana", Guyana },
            { "America/Havana", Cuba },
            { "America/Inuvik", America_Mountain },
            { "America/Juneau", Alaska },
            { "America/La_Paz", Bolivia },
            { "America/Maceio", Brasilia },
            { "America/Manaus", Amazon },
            { "America/Merida", America_Central },
            { "America/Nassau", America_Eastern },
            { "America/Panama", America_Eastern },
            { "America/Recife", Brasilia },
            { "America/Regina", America_Central },
            { "Asia/Chongqing", China },
            { "Asia/Hong_Kong", Hong_Kong },
            { "Asia/Pontianak", Indonesia_Western },
            { "Asia/Pyongyang", Korea },
            { "Asia/Qyzylorda", Kazakhstan_Western },
            { "Asia/Samarkand", Uzbekistan },
            { "Asia/Singapore", Singapore },
            { "Asia/Vientiane", Indochina },
            { "Europe/Andorra", Europe_Central },
            { "Europe/Belfast",
                new String[] {
                    "\u0413\u0440\u0438\u043d\u0432\u0438\u0447 \u0432\u0430\u049b\u0442\u0438",
                    "",
                    "\u0411\u0440\u0438\u0442\u0430\u043d\u0438\u044f \u0451\u0437\u0433\u0438 \u0432\u0430\u049b\u0442\u0438",
                    "",
                    "",
                    "",
                }
            },
            { "Europe/Tallinn", Europe_Eastern },
            { "Europe/Vatican", Europe_Central },
            { "Europe/Vilnius", Europe_Eastern },
            { "Indian/Mayotte", Africa_Eastern },
            { "Indian/Reunion", Reunion },
            { "Pacific/Easter", Easter },
            { "Pacific/Kosrae", Kosrae },
            { "Pacific/Majuro", Marshall_Islands },
            { "Pacific/Midway", Samoa },
            { "Pacific/Noumea", New_Caledonia },
            { "Pacific/Ponape", Ponape },
            { "Pacific/Saipan", Chamorro },
            { "Pacific/Tahiti", Tahiti },
            { "Pacific/Tarawa", Gilbert_Islands },
            { "Pacific/Wallis", Wallis },
            { "Africa/Blantyre", Africa_Central },
            { "Africa/Djibouti", Africa_Eastern },
            { "Africa/Freetown", GMT },
            { "Africa/Gaborone", Africa_Central },
            { "Africa/Khartoum", Africa_Central },
            { "Africa/Kinshasa", Africa_Western },
            { "Africa/Monrovia", GMT },
            { "Africa/Ndjamena", Africa_Western },
            { "Africa/Sao_Tome", GMT },
            { "Africa/Timbuktu", GMT },
            { "Africa/Windhoek", Africa_Central },
            { "America/Antigua", Atlantic },
            { "America/Caracas", Venezuela },
            { "America/Cayenne", French_Guiana },
            { "America/Cordoba", Argentina },
            { "America/Creston", America_Mountain },
            { "America/Curacao", Atlantic },
            { "America/Detroit", America_Eastern },
            { "America/Godthab", Greenland_Western },
            { "America/Grenada", Atlantic },
            { "America/Iqaluit", America_Eastern },
            { "America/Jamaica", America_Eastern },
            { "America/Managua", America_Central },
            { "America/Marigot", Atlantic },
            { "America/Mendoza", Argentina },
            { "America/Moncton", Atlantic },
            { "America/Nipigon", America_Eastern },
            { "America/Noronha", Noronha },
            { "America/Ojinaga", America_Mountain },
            { "America/Tijuana", America_Pacific },
            { "America/Toronto", America_Eastern },
            { "America/Tortola", Atlantic },
            { "America/Yakutat", Alaska },
            { "Asia/Choibalsan", Mongolia },
            { "Asia/Phnom_Penh", Indochina },
            { "Atlantic/Azores", Azores },
            { "Atlantic/Canary", Europe_Western },
            { "Atlantic/Faeroe", Europe_Western },
            { "Australia/Eucla", Australia_CentralWestern },
            { "Australia/Perth", Australia_Western },
            { "Europe/Belgrade", Europe_Central },
            { "Europe/Brussels", Europe_Central },
            { "Europe/Budapest", Europe_Central },
            { "Europe/Busingen", Europe_Central },
            { "Europe/Chisinau", Europe_Eastern },
            { "Europe/Guernsey", GMT },
            { "Europe/Helsinki", Europe_Eastern },
            { "Europe/Sarajevo", Europe_Central },
            { "Europe/Uzhgorod", Europe_Eastern },
            { "Indian/Maldives", Maldives },
            { "Pacific/Chatham", Chatham },
            { "Pacific/Fakaofo", Tokelau },
            { "Pacific/Gambier", Gambier },
            { "Pacific/Norfolk", Norfolk },
            { "SystemV/AST4ADT", Atlantic },
            { "SystemV/CST6CDT", America_Central },
            { "SystemV/EST5EDT", America_Eastern },
            { "SystemV/MST7MDT", America_Mountain },
            { "SystemV/PST8PDT", America_Pacific },
            { "SystemV/YST9YDT", Alaska },
            { "Africa/Bujumbura", Africa_Central },
            { "Africa/Mogadishu", Africa_Eastern },
            { "America/Anguilla", Atlantic },
            { "America/Asuncion", Paraguay },
            { "America/Barbados", Atlantic },
            { "America/Dominica", Atlantic },
            { "America/Edmonton", America_Mountain },
            { "America/Miquelon", Pierre_Miquelon },
            { "America/Montreal", America_Eastern },
            { "America/Resolute", America_Central },
            { "America/Santarem", Brasilia },
            { "America/Santiago", Chile },
            { "America/Shiprock", America_Mountain },
            { "America/St_Kitts", Atlantic },
            { "America/St_Lucia", Atlantic },
            { "America/Winnipeg", America_Central },
            { "Antarctica/Davis", Davis },
            { "Antarctica/Syowa", Syowa },
            { "Antarctica/Troll", GMT },
            { "Asia/Krasnoyarsk", Krasnoyarsk },
            { "Asia/Novosibirsk", Novosibirsk },
            { "Asia/Ulaanbaatar", Mongolia },
            { "Asia/Vladivostok", Vladivostok },
            { "Atlantic/Bermuda", Atlantic },
            { "Atlantic/Madeira", Europe_Western },
            { "Atlantic/Stanley", Falkland },
            { "Australia/Currie", Australia_Eastern },
            { "Australia/Darwin", Australia_Central },
            { "Australia/Hobart", Australia_Eastern },
            { "Australia/Sydney", Australia_Eastern },
            { "Europe/Amsterdam", Europe_Central },
            { "Europe/Gibraltar", Europe_Central },
            { "Europe/Ljubljana", Europe_Central },
            { "Europe/Mariehamn", Europe_Eastern },
            { "Europe/Podgorica", Europe_Central },
            { "Europe/Stockholm", Europe_Central },
            { "Europe/Volgograd", Volgograd },
            { "Indian/Christmas", Christmas },
            { "Indian/Kerguelen", French_Southern },
            { "Indian/Mauritius", Mauritius },
            { "Pacific/Auckland", New_Zealand },
            { "Pacific/Funafuti", Tuvalu },
            { "Pacific/Johnston", Hawaii_Aleutian },
            { "Pacific/Pitcairn", Pitcairn },
            { "Africa/Libreville", Africa_Western },
            { "Africa/Lubumbashi", Africa_Central },
            { "Africa/Nouakchott", GMT },
            { "Africa/Porto-Novo", Africa_Western },
            { "America/Araguaina", Brasilia },
            { "America/Boa_Vista", Amazon },
            { "America/Catamarca", Argentina },
            { "America/Fortaleza", Brasilia },
            { "America/Glace_Bay", Atlantic },
            { "America/Goose_Bay", Atlantic },
            { "America/Guatemala", America_Central },
            { "America/Guayaquil", Ecuador },
            { "America/Matamoros", America_Central },
            { "America/Menominee", America_Central },
            { "America/Monterrey", America_Central },
            { "America/Sao_Paulo", Brasilia },
            { "America/St_Thomas", Atlantic },
            { "America/Vancouver", America_Pacific },
            { "Antarctica/Mawson", Mawson },
            { "Antarctica/Vostok", Vostok },
            { "Asia/Kuala_Lumpur", Malaysia },
            { "Asia/Novokuznetsk", Krasnoyarsk },
            { "Europe/Bratislava", Europe_Central },
            { "Europe/Copenhagen", Europe_Central },
            { "Europe/Luxembourg", Europe_Central },
            { "Europe/San_Marino", Europe_Central },
            { "Europe/Simferopol", Moscow },
            { "Europe/Zaporozhye", Europe_Eastern },
            { "Pacific/Enderbury", Phoenix_Islands },
            { "Pacific/Galapagos", Galapagos },
            { "Pacific/Kwajalein", Marshall_Islands },
            { "Pacific/Marquesas", Marquesas },
            { "Pacific/Pago_Pago", Samoa },
            { "Pacific/Rarotonga", Cook },
            { "Pacific/Tongatapu", Tonga },
            { "Africa/Addis_Ababa", Africa_Eastern },
            { "Africa/Brazzaville", Africa_Western },
            { "Africa/Ouagadougou", GMT },
            { "America/Costa_Rica", America_Central },
            { "America/Grand_Turk", America_Eastern },
            { "America/Guadeloupe", Atlantic },
            { "America/Kralendijk", Atlantic },
            { "America/Louisville", America_Eastern },
            { "America/Martinique", Atlantic },
            { "America/Metlakatla", Alaska },
            { "America/Montevideo", Uruguay },
            { "America/Montserrat", Atlantic },
            { "America/Paramaribo", Suriname },
            { "America/St_Vincent", Atlantic },
            { "America/Whitehorse", America_Mountain },
            { "Antarctica/McMurdo", New_Zealand },
            { "Antarctica/Rothera", Rothera },
            { "Asia/Yekaterinburg", Yekaterinburg },
            { "Atlantic/Jan_Mayen", Europe_Central },
            { "Atlantic/Reykjavik", GMT },
            { "Atlantic/St_Helena", GMT },
            { "Australia/Adelaide", Australia_Central },
            { "Australia/Brisbane", Australia_Eastern },
            { "Australia/Lindeman", Australia_Eastern },
            { "Europe/Isle_of_Man", GMT },
            { "Europe/Kaliningrad", Europe_Eastern },
            { "Pacific/Kiritimati", Line_Islands },
            { "Africa/Johannesburg", Africa_Southern },
            { "America/El_Salvador", America_Central },
            { "America/Fort_Nelson", America_Mountain },
            { "America/Mexico_City", America_Central },
            { "America/Pangnirtung", America_Eastern },
            { "America/Porto_Velho", Amazon },
            { "America/Puerto_Rico", Atlantic },
            { "America/Rainy_River", America_Central },
            { "America/Tegucigalpa", America_Central },
            { "America/Thunder_Bay", America_Eastern },
            { "America/Yellowknife", America_Mountain },
            { "Arctic/Longyearbyen", Europe_Central },
            { "Atlantic/Cape_Verde", Cape_Verde },
            { "Australia/Lord_Howe", Lord_Howe },
            { "Australia/Melbourne", Australia_Eastern },
            { "Indian/Antananarivo", Africa_Eastern },
            { "Pacific/Guadalcanal", Solomon },
            { "Africa/Dar_es_Salaam", Africa_Eastern },
            { "America/Blanc-Sablon", Atlantic },
            { "America/Buenos_Aires", Argentina },
            { "America/Campo_Grande", Amazon },
            { "America/Danmarkshavn", GMT },
            { "America/Dawson_Creek", America_Mountain },
            { "America/Indiana/Knox", America_Central },
            { "America/Rankin_Inlet", America_Central },
            { "America/Scoresbysund", Greenland_Eastern },
            { "Antarctica/Macquarie", Australia_Eastern },
            { "Pacific/Port_Moresby", Papua_New_Guinea },
            { "America/Cambridge_Bay", America_Mountain },
            { "America/Coral_Harbour", America_Eastern },
            { "America/Indiana/Vevay", America_Eastern },
            { "America/Lower_Princes", Atlantic },
            { "America/Port_of_Spain", Atlantic },
            { "America/Santo_Domingo", Atlantic },
            { "America/St_Barthelemy", Atlantic },
            { "America/Swift_Current", America_Central },
            { "Antarctica/South_Pole", New_Zealand },
            { "Australia/Broken_Hill", Australia_Central },
            { "America/Bahia_Banderas", America_Central },
            { "America/Port-au-Prince", America_Eastern },
            { "Atlantic/South_Georgia", South_Georgia },
            { "America/Argentina/Salta", Argentina },
            { "America/Indiana/Marengo", America_Eastern },
            { "America/Indiana/Winamac", America_Eastern },
            { "America/Argentina/Tucuman", Argentina },
            { "America/Argentina/Ushuaia", Argentina },
            { "America/Indiana/Tell_City", America_Central },
            { "America/Indiana/Vincennes", America_Eastern },
            { "Antarctica/DumontDUrville", DumontDUrville },
            { "America/Argentina/La_Rioja", Argentina },
            { "America/Argentina/San_Juan", Argentina },
            { "America/Argentina/San_Luis", Argentina },
            { "America/Indiana/Petersburg", America_Eastern },
            { "America/Kentucky/Monticello", America_Eastern },
            { "America/North_Dakota/Beulah", America_Central },
            { "America/North_Dakota/Center", America_Central },
            { "timezone.excity.Etc/Unknown", "\u041d\u043e\u043c\u0430\u044a\u043b\u0443\u043c" },
            { "America/Argentina/Rio_Gallegos", Argentina },
            { "America/North_Dakota/New_Salem", America_Central },
            { "timezone.excity.America/Lower_Princes", "Lower Prince\u02bcs Quarter" },
        };
        return data;
    }
}
